/*
 *    Proxy.java
 *    Copyright (C) 2000 Stuart Yeates 
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

// the package we're in
package org.nzdl.gsdl;

// java standard library classes used
import java.io.*;
//import java.util.*;

import org.omg.CosNaming.*;
import org.omg.CORBA.ORB;

// local libraries
import org.nzdl.gsdl.corba.gsdlInterface.*;
import org.nzdl.gsdl.service.NzdlCollectionInfo; 
import org.nzdl.gsdl.service.NzdlQuery;
import org.nzdl.gsdl.service.NzdlRequest;
import org.nzdl.gsdl.service.NzdlResponse;
import org.nzdl.gsdl.service.NzdlResultSet;
import org.nzdl.gsdl.service.NzdlService;
import org.nzdl.gsdl.service.NzdlServiceServer;
import org.nzdl.gsdl.service.NzdlServiceClient;
import org.nzdl.gsdl.service.NzdlCrossCollectionWrapper;
import org.nzdl.gsdl.util.NzdlCorbaFactory;
import org.nzdl.gsdl.util.NzdlServiceFactory;
import org.nzdl.gsdl.util.NzdlPreferences;


/**
 * SimpleServer A very basic Greenstone server (not yet complete).
 *
 * @author stuart yeates (say1@cs.waikato.ac.nz)
 * @version $Revision: 2284 $
 * @see org.nzdl.gsdl.SimpleClient
 * @see org.nzdl.gsdl.service.NzdlServiceServer
 * @see org.omg.CORBA.ORB
 * @see <a href="http://www.nzdl.org/">The New Zealand Digital Library Project</a>
 * @see <a href="http://www.nzdl.org/fast-cgi-bin/library?&a=p&p=gsdl">Greenstone Digital Library Software</a>
 */


public class Proxy implements Serializable, Cloneable
{
  static String IORFileName = "/tmp/localcorba.proxy.objid";


  /**
   * Starts up a trivial server.
   *
   * @param args the arguments passed through to the orb initialisation code...
   */
  public static void main(String args[])
  {
    corbaComErrorHolder error = NzdlCorbaFactory.createComErrorHolder();
    try{
      NzdlPreferences.saving = false;
      NzdlPreferences.setBoolean("Connect to multiple servers", false);
      NzdlPreferences.setBoolean("Cache corba requests", true);
      NzdlPreferences.setBoolean("Save documents", true);
      NzdlPreferences.setBoolean("Log at the NzdlService level", false);

      NzdlService client = NzdlServiceFactory.createNzdlService(args,
								null,
								null,
								null,
								null);
      //client = new NzdlCrossCollectionWrapper(client,"");
      
      ORB orb = ORB.init(args, null);
      
      // Create the servant and register it with the ORB
      NzdlServiceServer simpleRef = new NzdlServiceServer(client);

      simpleRef.initialise(error);
      if (error.value.value() != corbaComError._corbaNoError) {
	System.err.println("CORBA error after initialisation:" + error.value.value());
      }
      
      orb.connect(simpleRef);
      System.err.println(orb.object_to_string(simpleRef));     
     
      NzdlServiceFactory.registerIOR(orb.object_to_string(simpleRef));

      try  {
	BufferedWriter output
	  = new BufferedWriter(new FileWriter(IORFileName));
	output.write(orb.object_to_string(simpleRef));
	output.flush();
      } catch (java.io.IOException e) {
	System.err.println("Error reading IOR file:\n" + e);
      }
      


      // Wait for invocations from clients
      java.lang.Object sync = new java.lang.Object();
      synchronized(sync){
        sync.wait();
      }
      
    } catch(Exception e) {
      System.err.println("CORBA error:" + error.value.value());     
      System.err.println("ERROR: " + e);
      e.printStackTrace(System.out);
    } 
    
  }
}






